@@ -17,17 +17,17 @@ with qw/
 __PACKAGE__->config( namespace => '' );
 
 
-sub base : Chained('/') PathPart('') CaptureArgs(0) {
-}
+# Every controller chains end up here at /base
+sub base : Chained('/') PathPart('') CaptureArgs(0) {}
 
-sub index : Chained('base') PathPart('') Args(0) : ActionClass('REST') {
+sub list : Chained('base') PathPart('') Args(0) : ActionClass('REST') {
     my ( $self, $c ) = @_;
     $c->stash( projects => $c->model('Projects')->get_all_projects );
 }
 
-sub index_GET { }
+sub list_GET { }
 
-sub default : Chained('base') PathPart('') Args() {
+sub default : Chained('base') PathPart('') Args() { # Capture all args
     my ( $self, $c ) = @_;
     $c->detach('/error404');
 }
@@ -44,7 +44,8 @@ Kaizendo::Controller::Root - Root Controller for Kaizendo
 
 =head1 DESCRIPTION
 
-[enter your description here]
+This is the root controller, which decides which actions are made based on
+the URLs requested.
 
 =head1 METHODS
 
@@ -68,17 +69,6 @@ Standard 404 error page
 
 Causes the REST serialization of the output.
 
-=head2 end
-
-Forwards to content serializer if there's no response body
-
-=cut
-
-sub end : Action {
-    my ( $self, $c ) = @_;
-    $c->forward('serialize')
-      unless $c->response->body;
-}
 
 =head1 AUTHORS, COPYRIGHT AND LICENSE
 
