@@ -4,6 +4,7 @@ use namespace::autoclean;
 
 BEGIN { extends 'Catalyst::Controller::REST'; }
 
+# Catalyst::Action::Serialize handles serializing
 sub serialize : ActionClass('Serialize') {}
 
 sub end : Action {
@@ -28,6 +29,14 @@ __PACKAGE__->config(
 
 App::Kaizendo::Web::ControllerBase::REST
 
+=head2 serialize
+
+The content serializer
+
+=head2 end
+
+Forwards to content serializer if there's no response body
+
 =head1 AUTHORS, COPYRIGHT AND LICENSE
 
 See L<App::Kaizendo> for Authors, Copyright and License information.
